@@ -20,6 +20,34 @@ from sklearn.naive_bayes import MultinomialNB
 from sklearn.metrics.pairwise import cosine_similarity
 from transformers import AutoTokenizer, AutoModel
 
+def deft_bert_compare_cls(model,tokenizer,sent1,sent2):
+    # https://towardsdatascience.com/bert-for-measuring-text-similarity-eec91c6bf9e1
+    max_length = 0
+    ls_sent = [sent1,sent2]
+    for s in ls_sent:
+        if len(s) > max_length:
+            max_length = len(s)
+    # initialize dictionary to store tokenized sentences
+    tokens = {'input_ids': [], 'attention_mask': []}
+    for sentence in ls_sent:
+        # encode each sentence and append to dictionary
+        # no need to specify add_special_tokens=True, but added for consistency, xiaoou
+        new_tokens = tokenizer.encode_plus(sentence, max_length=max_length,add_special_tokens=True,
+                                            truncation=True, padding='max_length',
+                                            return_tensors='pt')
+        tokens['input_ids'].append(new_tokens['input_ids'][0])
+        tokens['attention_mask'].append(new_tokens['attention_mask'][0])
+    # reformat list of tensors into single tensor
+    tokens['input_ids'] = torch.stack(tokens['input_ids'])
+    tokens['attention_mask'] = torch.stack(tokens['attention_mask'])
+    outputs = model(**tokens)
+    embeddings = outputs.last_hidden_state
+    first_sent_cls = embeddings[0][0][:]
+    second_sent_cls = embeddings[1][0][:]
+    return cosine_similarity(
+        [first_sent_cls.detach().numpy()],
+        [second_sent_cls.detach().numpy()]
+    ).flatten().flatten()[0]
 
 def deft_bert_compare_sent(model, tokenizer, sent1, sent2):
     # https://towardsdatascience.com/bert-for-measuring-text-similarity-eec91c6bf9e1
